import 'dart:io';

import 'package:recase/recase.dart';
import 'package:xml/xml.dart';

import 'validation.dart';
import 'xml_to_map.dart';

void main(List<String> args) {
  // File fontsConfigFile = File(args[0]);

  final File fontsConfigFile = File('./fonts/SimpleIcons.ttx');

  if (!fontsConfigFile.existsSync()) {
    print('config file not found');
    exit(0);
  }

  final String content = fontsConfigFile.readAsStringSync();
  final XmlDocument document = XmlDocument.parse(content);

  final Map<String, String> icons = xmlToIcons(document);

  final List<String> generatedOutput = <String>[
    "import 'package:flutter/widgets.dart';\n",
    "import 'icon_data.dart';\n\n",
    '// THIS FILE IS AUTOMATICALLY GENERATED!\n\n',
    '/// [SimpleIcons] offers the [IconData] of [https://simpleicons.org/]\n',
    'class SimpleIcons {\n'
  ];

  icons.forEach((String iconName, String iconUnicode) {
    iconName = validateVariableName(iconName);
    generatedOutput.add(
        'static const IconData ${ReCase(iconName).camelCase} = SimpleIconData($iconUnicode);\n');
  });

  generatedOutput.add('}\n');

  final File output = File('./lib/src/flutter_simple_icons.g.dart');
  output.writeAsStringSync(generatedOutput.join());
}
